# -*- coding: utf-8 -*-
from __future__ import unicode_literals

import re

import django.core.validators
from django.conf import settings
from django.db import models, migrations
import django.utils.timezone
import uuidfield.fields

import nodeconductor.core.models


class Migration(migrations.Migration):
    dependencies = [
        ('auth', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='User',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('password', models.CharField(max_length=128, verbose_name='password')),
                ('last_login', models.DateTimeField(default=django.utils.timezone.now, verbose_name='last login')),
                ('is_superuser', models.BooleanField(default=False,
                                                     help_text='Designates that this user has all permissions without explicitly assigning them.',
                                                     verbose_name='superuser status')),
                ('description', models.CharField(max_length=500, blank=True, verbose_name='description')),
                ('uuid', uuidfield.fields.UUIDField(unique=True, max_length=32, editable=False, blank=True)),
                ('username', models.CharField(
                    help_text='Required. 30 characters or fewer. Letters, numbers and @/./+/-/_ characters',
                    unique=True, max_length=30, verbose_name='username', validators=[
                        django.core.validators.RegexValidator(re.compile('^[\\w.@+-]+$'), 'Enter a valid username.',
                                                              'invalid')])),
                ('civil_number', models.CharField(max_length=10, null=True, default=None, blank=True, unique=True,
                                                  verbose_name='civil number')),
                ('full_name', models.CharField(max_length=100, verbose_name='full name', blank=True)),
                ('native_name', models.CharField(max_length=100, verbose_name='native name', blank=True)),
                ('phone_number', models.CharField(max_length=40, verbose_name='phone number', blank=True)),
                ('organization', models.CharField(max_length=80, verbose_name='organization', blank=True)),
                ('job_title', models.CharField(max_length=40, verbose_name='job title', blank=True)),
                ('email', models.EmailField(max_length=75, verbose_name='email address', blank=True)),
                ('is_staff', models.BooleanField(default=False,
                                                 help_text='Designates whether the user can log into this admin site.',
                                                 verbose_name='staff status')),
                ('is_active', models.BooleanField(default=True,
                                                  help_text='Designates whether this user should be treated as active. Unselect this instead of deleting accounts.',
                                                  verbose_name='active')),
                ('date_joined', models.DateTimeField(default=django.utils.timezone.now, verbose_name='date joined')),
                ('groups',
                 models.ManyToManyField(related_query_name='user', related_name='user_set', to='auth.Group', blank=True,
                                        help_text='The groups this user belongs to. A user will get all permissions granted to each of his/her group.',
                                        verbose_name='groups')),
                ('user_permissions',
                 models.ManyToManyField(related_query_name='user', related_name='user_set', to='auth.Permission',
                                        blank=True, help_text='Specific permissions for this user.',
                                        verbose_name='user permissions')),
            ],
            options={
                'verbose_name': 'user',
                'verbose_name_plural': 'users',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='SshPublicKey',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('uuid', uuidfield.fields.UUIDField(unique=True, max_length=32, editable=False, blank=True)),
                ('name', models.CharField(max_length=50, blank=True)),
                ('fingerprint', models.CharField(max_length=47)),
                ('public_key', models.TextField(validators=[django.core.validators.MaxLengthValidator(2000),
                                                            nodeconductor.core.models.validate_ssh_public_key])),
                ('user', models.ForeignKey(to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'unique_together': set([('user', 'name')]),
            },
            bases=(models.Model,),
        ),
    ]
